@@ -6,13 +6,21 @@ use Encode;
 Encode::perlio_ok ("utf16") or die ("can't read utf16");
 
 my $kfm = "KfM";
-my $buildVersion = "5.5.23";
-my $marketingVersion = "5.5.3";
-my $copyright = "Copyright 2006 Massachusetts Institute of Technology";
-my $shortCopyright = "Copyright 2006 MIT";
+my $buildVersion;
+my $marketingVersion;
+my $copyright = "Copyright 2004 Massachusetts Institute of Technology";
+my $shortCopyright = "Copyright 2004 MIT";
+my $root;
 
-my $root = shift @ARGV;
-$root or die "Usage: KerberosVersion <root directory>\n";
+my $usage = "Usage: KerberosVersion --build buildVersion --version versionString <root>\n";
+while ($_ = shift @ARGV) {
+    if    (/^--build/)   { $buildVersion = shift @ARGV; }
+    elsif (/^--version/) { $marketingVersion = shift @ARGV; }
+    else                 { $root = $_; }
+}
+
+$buildVersion or die $usage;
+$marketingVersion or die $usage;
 
 find (\&fixplists, $root); 
 
@@ -31,7 +39,7 @@ sub fixplists {
         }
         close $input;
         
-        # replace version strings
+# replace version strings
         
         $plist =~ s@(<key>CFBundleVersion</key>\s*<string>)[^<]*(</string>)@${1}${buildVersion}${2}@xg;
 # FIXME: CFBundleShortVersionString should be marketingVersion for next major release:
